@@ -443,7 +443,7 @@ class ClubMembership():
     '''
     # set up transformation to flatten record into ClubMembership object with attributes named as Transform keys
     # transform is from RunSignUp.members.get - see https://runsignup.com/API/club/:club_id/members/GET
-    xform = Transform({
+    xformmapping = {
         'user_id': lambda mem: mem['user']['user_id'],
         'membership_id': 'membership_id',
         'club_membership_level_name': 'club_membership_level_name',
@@ -457,13 +457,21 @@ class ClubMembership():
         'street': lambda mem: mem['user']['address']['street'] if 'address' in mem['user'] and 'street' in mem['user']['address'] else '',
         'city': lambda mem: mem['user']['address']['city'] if 'address' in mem['user'] and 'city' in mem['user']['address'] else '',
         'state': lambda mem: mem['user']['address']['state'] if 'address' in mem['user'] and 'state' in mem['user']['address'] else '',
+        'zipcode': lambda mem: mem['user']['address']['zipcode'] if 'address' in mem['user'] and 'state' in mem['user']['address'] else '',
         'primary_member': 'primary_member',
         'membership_start': 'membership_start',
         'membership_end': 'membership_end',
         'last_modified': 'last_modified',
-    },
+    }
+    # don't convert any of this to int / float, except user_id, membership_id, zipcode
+    knownstrings = list(xformmapping.keys())
+    knownstrings.remove('user_id')
+    knownstrings.remove('membership_id')
+    knownstrings.remove('zipcode')
+    xform = Transform(xformmapping,
         sourceattr=False,   # source is dict
-        targetattr=True     # target is ClubMembership
+        targetattr=True,    # target is ClubMembership
+        knownstrings=knownstrings,
     )
 
     def transform(self, rawrsumembership):
@@ -523,8 +531,9 @@ class ClubMemberships():
         self.city2mships = self.attr2mships['city']
         self.dob2mships = self.attr2mships['dob']
 
-        # collect nicknames for debugging
+        # collect nicknames, and lastnames for debugging
         self.nicknames = []
+        self.lastnames = []
 
         # second pass, try to identify members
         # main hash key is first user_id encountered for member (should be most recently used)
@@ -596,6 +605,12 @@ class ClubMemberships():
                             self.alias2userid[mship.user_id] = m.user_id
                             self.userid2mem[m.user_id].user_ids.append(mship.user_id)
                             self.userid2mem[m.user_id].mships.append(mship)
+
+                            # for debugging
+                            self.lastnames.append('{} ; {}'.format(
+                                '{} {}'.format(m.first_name, m.last_name),
+                                '{} {}'.format(mship.first_name, mship.last_name)
+                            ))
                             break
 
                 # maybe member is using a nickname which is different from a first name used in an earlier membership.
